@@ -18,17 +18,21 @@
  * @package  Net_URL2
  * @author   Some Pear Developers <pear@php.net>
  * @license  https://spdx.org/licenses/BSD-3-Clause BSD-3-Clause
- * @version  Release: 2.0.6
+ * @version  Release: 2.0.7
  * @link     https://pear.php.net/package/Net_URL2
  */
 class Net_URL2Test extends PHPUnit_Framework_TestCase
 {
     /**
      * Tests setting an empty userinfo part
-     * Also: Regression test for Bug #20013
+     * Also: Regression test for Bug #20013 and Bug #20399
      *
+     * @covers Net_URL2::setUserinfo
+     * @covers Net_URL2::getUserinfo
+     * @covers Net_URL2::getURL
      * @return void
      * @link https://pear.php.net/bugs/bug.php?id=20013
+     * @link https://pear.php.net/bugs/bug.php?id=20399
      */
     public function testSetEmptyUserinfo()
     {
@@ -39,6 +43,35 @@ class Net_URL2Test extends PHPUnit_Framework_TestCase
         $this->assertSame('http://www.example.com/', $url->getURL());
         $url->setUserinfo('');
         $this->assertSame('http://www.example.com/', $url->getURL());
+        $this->assertSame('', $url->getUserinfo());
+        $url->setUserinfo(false);
+        $this->assertSame('http://www.example.com/', $url->getURL());
+        $this->assertFalse($url->getUserinfo());
+    }
+
+    /**
+     * Tests an URL with no userinfo and normalization
+     *
+     * Also: Regression test for Bug #20385
+     *
+     * @covers Net_URL2::getUserinfo
+     * @covers Net_URL2::normalize
+     * @covers Net_URL2::getNormalizedURL
+     * @return void
+     * @link https://pear.php.net/bugs/bug.php?id=20385
+     */
+    public function testNoUserinfoAndNormalize()
+    {
+        $testUrl = 'http://www.example.com/';
+
+        $url = new Net_URL2($testUrl);
+        $this->assertFalse($url->getUserinfo());
+
+        $url->normalize();
+        $this->assertFalse($url->getUserinfo());
+
+        $this->assertEquals($testUrl, $url->getURL());
+        $this->assertEquals($testUrl, $url->getNormalizedURL());
     }
 
     /**
